@@ -8,19 +8,22 @@ import os
 class Plot:
     """ Plot generator lib"""
 
+    __css_base = ".modebar {display: none;} \n.modebar-container {display: none;} "
+
     def export(self, chart, filename, css=None):
         """ create html export and add css to it"""
         html_filename = f"{filename.split('.')[0]}.html"
+        html_exist = os.path.exists(html_filename)
         chart.write_html(html_filename)
         html_map = None
         if css is None:
-            css = ".modebar {display: none;}"
+            css = self.__css_base
         else:
-            css = css + "\n.modebar {display: none;}"
+            css = css + self.__css_base
         with open(html_filename) as f:
             html_map = f.read()
             result = html_map.replace(
-                "<body>", f'<body><style id="naas_css">{css}</style>'
+                "</head>", f'<style id="naas_css">{css}</style></head>'
             )
         with open(html_filename, "w") as f:
             f.write(result)
@@ -30,11 +33,10 @@ class Plot:
             json = {
                 "output": "screenshot",
                 "html": html_text,
-                #               "waitFor": 10000,
                 "emulateScreenMedia": True,
                 "ignoreHttpsErrors": True,
                 "scrollPage": False,
-                "screenshot": {"type": "png"},
+                "screenshot": {"type": "png", "selector": ".cartesianlayer"},
             }
             req = requests.post(
                 url=f"{os.environ.get('SCREENSHOT_API', 'http://naas-screenshot:9000')}/api/render",
@@ -42,7 +44,8 @@ class Plot:
             )
             req.raise_for_status()
             open(filename, "wb").write(req.content)
-            os.remove(html_filename)
+            if not html_exist:
+                os.remove(html_filename)
         elif not filename.endswith(".png") and not filename.endswith(".html"):
             print("Not supported for now")
             os.remove(html_filename)
@@ -52,18 +55,30 @@ class Plot:
     def stock(
         self,
         stock_companies,
-        start=(dt.datetime.today() - dt.timedelta(days=365)),
-        end=dt.datetime.today(),
+        date_from=-30,
+        date_to="today",
         interval="1d",
         kind="candlestick",
-        filter=True,
+        filter=False,
         filter_title="Stock",
     ):
-        """ generate financial_candlestick html """
+        """ generate financial_chart """
+        if isinstance(stock_companies, str):
+            stock_companies = [stock_companies]
+        if isinstance(date_from, int) and date_from < 0:
+            date_from = dt.datetime.today() + dt.timedelta(days=date_from)
+        else:
+            raise ValueError(f"date_from ({date_from}) cannot be positive")
+        if isinstance(date_to, int) and date_to > 0:
+            date_to = dt.datetime.today() + dt.timedelta(days=date_to)
+        if isinstance(date_to, str) and date_to == "today":
+            date_to = dt.datetime.today()
+        else:
+            raise ValueError(f"date_to ({date_to}) cannot be negative")
         stocks = []
         data = []
-        period1 = start.strftime("%s")
-        period2 = end.strftime("%s")
+        period1 = date_from.strftime("%s")
+        period2 = date_to.strftime("%s")
         buttons = []
         buttons.append(
             dict(
@@ -149,6 +164,8 @@ class Plot:
         fig = go.Figure(data=list(data), layout=layout)
         if filter:
             fig.update_layout(
+                template="plotly_white",
+                margin=dict(t=0, b=0, l=0, r=0),
                 annotations=[
                     dict(
                         text=filter_title,
@@ -159,7 +176,7 @@ class Plot:
                         align="left",
                         showarrow=False,
                     )
-                ]
+                ],
             )
         return fig
 
